@@ -13,7 +13,7 @@ extern "C" {
 
 
 /** Defines the Baresip version string */
-#define BARESIP_VERSION "3.1.0"
+#define BARESIP_VERSION "3.2.0"
 
 
 #ifndef NET_MAX_NS
@@ -382,8 +382,14 @@ struct config_avt {
 	struct range rtp_ports; /**< RTP port range                 */
 	struct range rtp_bw;    /**< RTP Bandwidth range [bit/s]    */
 	bool rtcp_mux;          /**< RTP/RTCP multiplexing          */
-	enum jbuf_type jbtype;  /**< Jitter buffer type             */
-	struct range jbuf_del;  /**< Delay, number of frames        */
+	struct {
+		enum jbuf_type jbtype;  /**< Jitter buffer type     */
+		struct range jbuf_del;  /**< Delay, number of frames*/
+	} audio;
+	struct {
+		enum jbuf_type jbtype;  /**< Jitter buffer type     */
+		struct range jbuf_del;  /**< Delay, number of frames*/
+	} video;
 	bool rtp_stats;         /**< Enable RTP statistics          */
 	uint32_t rtp_timeout;   /**< RTP Timeout in seconds (0=off) */
 	bool bundle;            /**< Media Multiplexing (BUNDLE)    */
